==> com.liferay.layout.content.page.editor.web-2.0.74.jar: META-INF/resources/page_editor/app/actions/changeMasterLayout.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.74/page_editor/app/actions/changeMasterLayout", ['module', 'exports', 'require', './types'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports["default"] = changeMasterLayout;

    var _types = require("./types");

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */
    function changeMasterLayout(_ref) {
      var _ref$fragmentEntryLin = _ref.fragmentEntryLinks,
          fragmentEntryLinks = _ref$fragmentEntryLin === void 0 ? [] : _ref$fragmentEntryLin,
          _ref$masterLayoutData = _ref.masterLayoutData,
          masterLayoutData = _ref$masterLayoutData === void 0 ? null : _ref$masterLayoutData,
          _ref$masterLayoutPlid = _ref.masterLayoutPlid,
          masterLayoutPlid = _ref$masterLayoutPlid === void 0 ? 0 : _ref$masterLayoutPlid;
      return {
        fragmentEntryLinks: fragmentEntryLinks,
        masterLayoutData: masterLayoutData,
        masterLayoutPlid: masterLayoutPlid,
        type: _types.CHANGE_MASTER_LAYOUT
      };
    }
    //# sourceMappingURL=changeMasterLayout.js.map
  }
});
//# sourceMappingURL=changeMasterLayout.js.map

==> com.liferay.layout.content.page.editor.web-2.0.122.jar: META-INF/resources/page_editor/app/actions/changeMasterLayout.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.122/page_editor/app/actions/changeMasterLayout", ['module', 'exports', 'require', './types'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = changeMasterLayout;

    var _types = require("./types");

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */
    function changeMasterLayout(_ref) {
      var _ref$fragmentEntryLin = _ref.fragmentEntryLinks,
          fragmentEntryLinks = _ref$fragmentEntryLin === void 0 ? [] : _ref$fragmentEntryLin,
          _ref$masterLayoutData = _ref.masterLayoutData,
          masterLayoutData = _ref$masterLayoutData === void 0 ? null : _ref$masterLayoutData,
          _ref$masterLayoutPlid = _ref.masterLayoutPlid,
          masterLayoutPlid = _ref$masterLayoutPlid === void 0 ? 0 : _ref$masterLayoutPlid;
      return {
        fragmentEntryLinks: fragmentEntryLinks,
        masterLayoutData: masterLayoutData,
        masterLayoutPlid: masterLayoutPlid,
        type: _types.CHANGE_MASTER_LAYOUT
      };
    }
    //# sourceMappingURL=changeMasterLayout.js.map
  }
});
//# sourceMappingURL=changeMasterLayout.js.map
